@@ -25,7 +25,9 @@ class Network(BaseModel):
 
     def __repr__(self) -> str:
         return "Network({ip}/{netmask} [{type}])".format(
-            ip=self.ip_address, netmask=self.netmask, type=self.type,
+            ip=self.ip_address,
+            netmask=self.netmask,
+            type=self.type,
         )
 
 
@@ -391,6 +393,7 @@ class LoadBalancer(BaseModel):
     forwarding_rules: List[ForwardingRule]
 
     # optional params
+    size: Optional[str]
     ip: Optional[str]
     algorithm: Optional[str]
     status: Optional[str]
@@ -447,6 +450,15 @@ class Registry(BaseModel):
         latest_tag: Tag
         tag_count: int
 
+    class GarbageCollection(BaseModel):
+        uuid: str
+        registry_name: str
+        blobs_deleted: int
+        status: str
+        freed_bytes: int
+        created_at: datetime
+        updated_at: datetime
+
     name: str
     created_at: Optional[datetime]
 
